import { __decorate, __param, __metadata } from 'tslib';
import { InjectionToken, defineInjectable, inject, Injectable, Inject, EventEmitter, ViewChild, ElementRef, Component, Input, Output, NgModule, HostListener, Renderer2 } from '@angular/core';
import { CommonModule, DatePipe } from '@angular/common';
import { HttpHeaders, HttpClient, HttpErrorResponse, HttpClientModule, HTTP_INTERCEPTORS } from '@angular/common/http';
import { from, Subject, BehaviorSubject } from 'rxjs';
import { mergeMap } from 'rxjs/operators';
import * as Keycloak_ from 'keycloak-js';
import { NgbModule } from '@ng-bootstrap/ng-bootstrap';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { trigger, transition, style, animate } from '@angular/animations';
import { FormsModule } from '@angular/forms';
import { ToastrService, ToastrModule } from 'ngx-toastr';
import { MatDialogRef, MatDialog as MatDialog$1, MatDialogModule, MatButtonModule } from '@angular/material';
import { MatDialog } from '@angular/material/dialog';
import { MatSelectModule } from '@angular/material/select';
import { RouterModule } from '@angular/router';
import { PerfectScrollbarModule } from 'ngx-perfect-scrollbar';

const LUMILOGIN_URL = new InjectionToken('LUMILOGIN_URL');
const LUMILOGIN_REALM = new InjectionToken('LUMILOGIN_REALM');
const LUMILOGIN_CLIENTID = new InjectionToken('LUMILOGIN_CLIENTID');
const LUMILOGIN_SECRET = new InjectionToken('LUMILOGIN_SECRET');
const APPLICATION_NAME = new InjectionToken('APPLICATION_NAME');
const THEME_CONFIG = new InjectionToken('THEME_CONFIG');
const URL_API_LUMILOGIN = new InjectionToken('URL_API_LUMILOGIN');
const SHOW_SEARCH_BAR = new InjectionToken('SHOW_SEARCH_BAR');
const SHOW_LANG_SELECTOR = new InjectionToken('SHOW_LANG_SELECTOR');
const DOC_URL = new InjectionToken('DOC_URL');
const SHOW_HELP = new InjectionToken('SHOW_HELP');
const SHOW_CGU = new InjectionToken('SHOW_CGU');

var LumiloginService_1;
const Keycloak = Keycloak_;
// @dynamic
let LumiloginService = LumiloginService_1 = class LumiloginService {
    constructor(url, realm, clientId, secret) {
        this.url = url;
        this.realm = realm;
        this.clientId = clientId;
        this.secret = secret;
        LumiloginService_1.url = url;
        LumiloginService_1.realm = realm;
        LumiloginService_1.clientId = clientId;
        LumiloginService_1.secret = secret;
    }
    static init() {
        const keycloakAuth = Keycloak({
            url: this.url,
            realm: this.realm,
            clientId: this.clientId,
            secret: this.secret,
            'ssl-required': 'external',
            'public-client': true
        });
        LumiloginService_1.auth.loggedIn = false;
        return new Promise((resolve, reject) => {
            keycloakAuth.init({ onLoad: 'login-required', checkLoginIframe: false })
                .success(() => {
                LumiloginService_1.auth.loggedIn = false;
                LumiloginService_1.auth.authz = keycloakAuth;
                resolve();
            })
                .error(() => {
                reject();
            });
        });
    }
    login() {
        LumiloginService_1.auth.authz.login().success(() => {
            LumiloginService_1.auth.loggedIn = true;
        });
    }
    getToken() {
        return new Promise((resolve, reject) => {
            if (LumiloginService_1.auth.authz.token) {
                LumiloginService_1.auth.authz
                    .updateToken(5)
                    .success(() => {
                    resolve(LumiloginService_1.auth.authz.token);
                })
                    .error(() => {
                    reject('Failed to refresh token');
                });
            }
            else {
                reject('Not logged in');
            }
        });
    }
    isLoggedIn() {
        return LumiloginService_1.auth.authz.authenticated;
    }
    getFullName() {
        let tokenParsed = LumiloginService_1.auth.authz.tokenParsed;
        return tokenParsed.name || tokenParsed.preferred_username;
    }
    getParsedToken() {
        return LumiloginService_1.auth.authz.tokenParsed;
    }
    getUserId() {
        return LumiloginService_1.auth.authz.tokenParsed.sub;
    }
    getRoles() {
        return LumiloginService_1.auth.authz.tokenParsed.resource_access.lumiplay_api.roles;
    }
    getGroups() {
        return LumiloginService_1.auth.authz.tokenParsed.group;
    }
    getCompanyName() {
        return LumiloginService_1.auth.authz.tokenParsed.company;
    }
    getApplications() {
        return LumiloginService_1.auth.authz.tokenParsed.application || [];
    }
    getKeycloakAuth() {
        return LumiloginService_1.auth.authz;
    }
    logout() {
        LumiloginService_1.auth.authz.logout({ redirectUri: document.baseURI }).success(() => {
            LumiloginService_1.auth.loggedIn = false;
            LumiloginService_1.auth.authz = null;
        });
    }
    get searchObservable() {
        return this._searchObservable;
    }
    set searchObservable(searchObservable) {
        this._searchObservable = searchObservable;
    }
};
LumiloginService.auth = {};
LumiloginService.url = "";
LumiloginService.realm = "";
LumiloginService.clientId = "";
LumiloginService.secret = "";
LumiloginService.ngInjectableDef = defineInjectable({ factory: function LumiloginService_Factory() { return new LumiloginService(inject(LUMILOGIN_URL), inject(LUMILOGIN_REALM), inject(LUMILOGIN_CLIENTID), inject(LUMILOGIN_SECRET)); }, token: LumiloginService, providedIn: "root" });
LumiloginService = LumiloginService_1 = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __param(0, Inject(LUMILOGIN_URL)),
    __param(1, Inject(LUMILOGIN_REALM)),
    __param(2, Inject(LUMILOGIN_CLIENTID)),
    __param(3, Inject(LUMILOGIN_SECRET)),
    __metadata("design:paramtypes", [String, String, String, String])
], LumiloginService);

let LumiloginInterceptorService = class LumiloginInterceptorService {
    constructor(lumiloginService) {
        this.lumiloginService = lumiloginService;
    }
    intercept(request, next) {
        if (this.lumiloginService.isLoggedIn()) {
            return this.getUserToken().pipe(mergeMap((token) => {
                if (token) {
                    request = request.clone({
                        setHeaders: {
                            Authorization: `Bearer ${token}`
                        }
                    });
                }
                return next.handle(request);
            }));
        }
        return next.handle(request);
    }
    getUserToken() {
        const tokenPromise = this.lumiloginService.getToken();
        const tokenObservable = from(tokenPromise);
        return tokenObservable;
    }
};
LumiloginInterceptorService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [LumiloginService])
], LumiloginInterceptorService);

const applications = [
    { name: 'LumiData', url: 'https://lumidata.com', icon: 'ft-database item-badge mb-4', logo: "" },
    { name: 'LumiBackOffice', url: 'https://lumibackoffice.com', icon: 'ft-activity item-badge mb-4', logo: "" },
    { name: 'LumiBridge', url: 'https://lumibridge.com', icon: 'ft-globe item-badge mb-4', logo: "" },
    { name: 'LumiFlow', url: 'https://lumiflow.com', icon: 'ft-layers item-badge mb-4', logo: "" },
    { name: 'LumiPlay Engine', url: 'https://lumiplay.net', icon: 'ft-airplay item-badge mb-4', logo: "logo_lumiplay.png" },
    { name: 'MountainLive', url: 'https://mountain-live.com', icon: 'ft-triangle item-badge mb-4', logo: "logo-mountain-live.png" }
];

let TranslationLoaderService = class TranslationLoaderService {
    constructor(translate) {
        this.translate = translate;
        this.DEFAULT_LANG = 'fr';
        this.languages = [
            {
                lang: 'fr',
                name: 'Français',
                flag: 'assets/img/flags/France.png'
            },
            {
                lang: 'en',
                name: 'English',
                flag: 'assets/img/flags/us.png'
            },
        ];
    }
    loadTranslations(...args) {
        const locales = [...args];
        locales.forEach((locale) => {
            // use setTranslation() with the third argument set to true
            // to append translations instead of replacing them
            this.translate.setTranslation(locale.lang, locale.data, true);
        });
    }
    /*
     * Set initial language
     */
    setInitLang() {
        this.setLanguage(this.getActiveLanguage());
    }
    setLanguage(lang) {
        if (lang) {
            // Set the selected language for the toolbar
            this.languages.forEach((language) => {
                if (language.lang === lang) {
                    this.selectedLanguage = language;
                }
            });
            this.translate.use(lang);
            localStorage.setItem('language', lang);
        }
    }
    getActiveLanguage() {
        return localStorage.getItem('language') || this.translate.currentLang || this.DEFAULT_LANG;
    }
};
TranslationLoaderService.ngInjectableDef = defineInjectable({ factory: function TranslationLoaderService_Factory() { return new TranslationLoaderService(inject(TranslateService)); }, token: TranslationLoaderService, providedIn: "root" });
TranslationLoaderService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [TranslateService])
], TranslationLoaderService);

let NavigationService = class NavigationService {
    constructor() {
        this.navigationChange = new EventEmitter();
        this.navigation = null;
    }
    getNavigation() {
        return this.navigation;
    }
    setNavigation(navigation) {
        this.navigationChange.emit(navigation);
        this.navigation = navigation;
    }
    hasNavigationContent() {
        return this.navigation && this.navigation.length > 0;
    }
};
NavigationService.ngInjectableDef = defineInjectable({ factory: function NavigationService_Factory() { return new NavigationService(); }, token: NavigationService, providedIn: "root" });
NavigationService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [])
], NavigationService);

var HeaderComponent_1;
let HeaderComponent = HeaderComponent_1 = class HeaderComponent {
    constructor(lumilogin, url, realm, applicationName, show_Search_Bar_All, show_Lang_Selector, _translationLoaderService, navigationService) {
        this.lumilogin = lumilogin;
        this.url = url;
        this.realm = realm;
        this.applicationName = applicationName;
        this.show_Search_Bar_All = show_Search_Bar_All;
        this.show_Lang_Selector = show_Lang_Selector;
        this._translationLoaderService = _translationLoaderService;
        this.navigationService = navigationService;
        this.LOGO_PATH = "assets/img/logos/";
        this.brandedLumi = true;
        this.showSearchBarAll = true;
        this.showLangSelector = true;
        this.showSearchBar = false;
        this.logo_img = '';
        HeaderComponent_1.url = url;
        HeaderComponent_1.realm = realm;
        this.appNameBasic = applicationName;
        this.name = this.displayAppName(applicationName);
        this.showSearchBarAll = show_Search_Bar_All;
        this.showLangSelector = show_Lang_Selector;
        this.searchSubject = new Subject();
        this.searchObservable = this.searchSubject.asObservable();
        this.lumilogin.searchObservable = this.searchObservable;
        const element = document.createElement('link');
        element.rel = 'stylesheet';
        const pageUrl = document.location.href.toLowerCase();
        if (pageUrl.includes("lumiplay")) {
            element.href = 'city.css';
            this.logo_img = 'lumiplay.png';
        }
        else if (pageUrl.includes("mountainlive")) {
            element.href = 'mountain.css';
            this.logo_img = 'mountain-live.png';
        }
        else {
            element.href = 'group.css';
            this.logo_img = 'lumiplan.png';
        }
        document.body.appendChild(element);
    }
    ngOnInit() {
        this.lumiloginAuth = this.lumilogin.getKeycloakAuth();
        this.applications = applications;
    }
    login() {
        this.lumilogin.login();
    }
    logout() {
        this.lumilogin.logout();
    }
    displayUserInfo() {
        return this.lumilogin.getFullName();
    }
    getCompanyName() {
        return this.lumilogin.getCompanyName() === '' ? '-' : this.lumilogin.getCompanyName();
    }
    getAccountUrl() {
        return HeaderComponent_1.url + 'realms/' + HeaderComponent_1.realm + '/account';
    }
    initialName() {
        if (this.lumilogin.getFullName() === undefined) {
            return '';
        }
        else {
            return this.lumilogin.getFullName().split(' ').map(s => s[0]).join('');
        }
    }
    isLoggedIn() {
        return this.lumilogin.isLoggedIn();
    }
    displayAppName(name) {
        let nameApp = 'BackOffice';
        applications.forEach(app => {
            if (app.name.toLowerCase() === name.toLowerCase()) {
                this.brandedLumi = app.name.indexOf('Lumi') !== -1;
                nameApp = app.name.replace('Lumi', '');
            }
        });
        return nameApp;
    }
    showAppMenu() {
        const arr = this.filterApplications();
        if (arr.length === 0) {
            return false;
        }
        return !(arr.length <= 1 && arr[0].name.toLowerCase() === this.appNameBasic.toLowerCase());
    }
    filterApplications() {
        return applications.filter(app => {
            return this.lumilogin.getApplications().includes(app.name.toLowerCase());
        });
    }
    setLanguage(lang) {
        this._translationLoaderService.setLanguage(lang);
    }
    onSearchBarChange() {
        this.searchSubject.next(this.searchString);
    }
    onClickCloseSearchBar() {
        this.showSearchBar = false;
        this.searchString = "";
        this.searchSubject.next(this.searchString);
    }
    onToggleSearchBarClick() {
        this.showSearchBar = !this.showSearchBar;
        if (this.searchBar)
            this.searchBar.nativeElement.focus();
    }
};
HeaderComponent.url = '';
HeaderComponent.realm = '';
__decorate([
    ViewChild('SearchBar'),
    __metadata("design:type", ElementRef)
], HeaderComponent.prototype, "searchBar", void 0);
HeaderComponent = HeaderComponent_1 = __decorate([
    Component({
        selector: 'app-header',
        template: "<div class=\"navbar navbar-expand navbar-dark fixed-top header bg-primary text-white\">\n\t<ul class=\"navbar-nav mr-auto\">\n\t\t<li>\n\t\t\t<a class=\"navbar-brand d-none d-sm-inline-block\" href=\"index\">\n\t\t\t\t<ng-container><img class=\"logo\" src=\"{{LOGO_PATH + logo_img}}\"></ng-container>\n\t\t\t</a>\n\t\t</li>\n\t</ul>\n\t<ul class=\"navbar-nav\">\n\t\t<li class=\"navbar-item\" *ngIf=\"showSearchBar && showSearchBarAll\">\n\t\t\t<div class=\"searchbar-container\" @searchBar>\n\t\t\t\t<input class=\"searchbar-input\" type=\"text\" placeholder=\"{{'HEADER.SEARCH' | translate}}\" [(ngModel)]=\"searchString\" (ngModelChange)=\"onSearchBarChange()\" #SearchBar>\n\t\t\t\t<i class=\"material-icons searchbar-icon clickable\" (click)=\"onClickCloseSearchBar()\">clear</i>\n\t\t\t</div>\n\t\t</li>\n\t\t<li class=\"navbar-item\" *ngIf=\"!showSearchBar && showSearchBarAll\">\n\t\t\t<i @searchIcon class=\"material-icons clickable\" (click)=\"onToggleSearchBarClick()\" style=\"font-size: 24px;margin-top: 3px;\">search</i>\n\t\t</li>\n\t\t<li class=\"nav-item dropdown d-none d-sm-inline-block\" ngbDropdown display=\"dynamic\" *ngIf=\"isLoggedIn()\">\n\t\t\t<a class=\"nav-link dropdown-toggle megamenu-link\" href=\"javascript:;\" ngbDropdownToggle *ngIf=\"showAppMenu()\">\n\t\t\t\t<i class=\"material-icons\" style=\"margin-top: 3px;\">apps</i><i class=\"material-icons\">arrow_drop_down</i>\n\t\t\t</a>\n\t\t\t<div class=\"dropdown-menu nav-megamenu\" ngbDropdownMenu style=\"min-width: 400px\">\n\t\t\t\t<div class=\"row m-0\">\n\t\t\t\t\t<div class=\"col-6\" *ngFor=\"let app of filterApplications(); let i = index\">\n\t\t\t\t\t\t<a class=\"mega-menu-item\" [ngClass]=\"{'bg-primary text-white' : app.name.toLowerCase() === ('lumi'+name.toLowerCase())}\" href={{app.url}}>\n\t\t\t\t\t\t\t<i class={{app.icon}} [ngClass]=\"{'text-white' : app.name.toLowerCase() === ('lumi'+name.toLowerCase())}\"></i>\n\t\t\t\t\t\t\t<h5 class=\"mb-2\">{{app.name}}</h5>\n\t\t\t\t\t\t</a>\n\t\t\t\t\t</div>\n\t\t\t\t</div>\n\t\t\t</div>\n\t\t</li>\n\t\t<li class=\"nav-divider\" *ngIf=\"isLoggedIn() && showLangSelector\"></li>\n\t\t<li class=\"nav-item\" placement='bottom-right' ngbDropdown *ngIf=\"showLangSelector\">\n\t\t\t<a class=\"nav-link d-inline-flex align-items-center no-arrow\" ngbDropdownToggle href=\"javascript:;\">\n\t\t\t\t<img src=\"{{_translationLoaderService.selectedLanguage.flag}}\" width=\"24\" alt=\"\">\n\t\t\t</a>\n\t\t\t<div ngbDropdownMenu>\n\t\t\t\t<a *ngFor=\"let lang of _translationLoaderService.languages\" class=\"dropdown-item d-flex align-items-center\" (click)=\"setLanguage(lang.lang)\" href=\"javascript:;\">\n\t\t\t\t\t<img class=\"mr-3\" src=\"{{lang.flag}}\" width=\"24\" alt=\"\">{{lang.name}}\n\t\t\t\t</a>\n\t\t\t</div>\n\t\t</li>\n\t\t<li class=\"nav-divider\" *ngIf=\"isLoggedIn() && showLangSelector\"></li>\n\t\t<li class=\"nav-item dropdown\" ngbDropdown placement='bottom-right' *ngIf=\"isLoggedIn(); else notLog\">\n\t\t\t<a class=\"nav-link dropdown-toggle no-arrow d-inline-flex align-items-center\" ngbDropdownToggle href=\"javascript:;\">\n\t\t\t\t<span class=\"d-none d-sm-inline-block mr-2\">{{ displayUserInfo() }}</span>\n\t\t\t\t<button class=\"btn btn-outline-primary btn-floating\" type=\"button\">{{ initialName() }}</button>\n\t\t\t</a>\n\t\t\t<div class=\"dropdown-menu pt-0 pb-4\" id=\"dropdown_nav_user\" ngbDropdownMenu style=\"min-width: 280px\">\n\t\t\t\t<div class=\"p-4 mb-4 media align-items-center bg-primary text-white\">\n\t\t\t\t\t<div class=\"media-body\">\n\t\t\t\t\t\t<h5 class=\"mb-1\">{{ displayUserInfo() }}</h5>\n\t\t\t\t\t\t<div class=\"font-13\">{{ getCompanyName() }}</div>\n\t\t\t\t\t</div>\n\t\t\t\t</div>\n\t\t\t\t<a class=\"dropdown-item d-flex align-items-center\" href=\"{{getAccountUrl()}}\"><i class=\"ft-user mr-3 font-18 text-muted\"></i>{{'HEADER.PROFILE' | translate}}</a>\n\t\t\t\t<a class=\"dropdown-item d-flex align-items-center\" href=\"javascript:;\"><i class=\"ft-settings mr-3 font-18 text-muted\"></i>{{'HEADER.SETTINGS' | translate}}</a>\n\t\t\t\t<div class=\"dropdown-divider my-3\"></div>\n\t\t\t\t<div class=\"mx-4\">\n\t\t\t\t\t<a class=\"btn btn-link p-0\" style=\"cursor: pointer;\"><span class=\"btn-icon\" (click)=\"logout()\"><i class=\"ft-power mr-2 font-18\"></i>{{'HEADER.LOGOUT' | translate}}</span></a>\n\t\t\t\t</div>\n\t\t\t</div>\n\t\t</li>\n\t\t<ng-template #notLog>\n\t\t\t<li class=\"nav-item\">\n\t\t\t\t<a class=\"nav-link\" style=\"cursor: pointer;\" (click)=\"login()\" href=\"javascript:;\"><i class=\"ft-power mr-2 font-18\"></i> {{'HEADER.LOGIN' | translate}}</a>\n\t\t\t</li>\n\t\t</ng-template>\n\t</ul>\n</div>\n\n<app-header-nav *ngIf=\"navigationService.hasNavigationContent()\" class=\"header-nav\"></app-header-nav>",
        animations: [
            trigger('searchBar', [
                transition(':enter', [
                    style({
                        width: 0
                    }),
                    animate('500ms', style({
                        width: '*'
                    }))
                ]),
                transition(':leave', [
                    animate('500ms', style({
                        opacity: 0
                    }))
                ])
            ]),
            trigger('searchIcon', [
                transition(':enter', [
                    style({ opacity: 0 }),
                    animate('500ms', style({
                        opacity: 1
                    }))
                ]),
                transition(':leave', [
                    animate('500ms', style({
                        opacity: 0
                    }))
                ])
            ]),
        ],
        styles: [".searchbar-container{background-color:#fff;vertical-align:middle;display:flex;border-radius:30px;width:100%;-webkit-animation-name:openSearch;animation-name:openSearch;-webkit-animation-duration:4s;animation-duration:4s;overflow:hidden}.searchbar-input{background-color:rgba(255,255,255,0);outline:0;border:0 solid;resize:none;height:100%;padding:6px 0 6px 6px}.searchbar-icon{margin:auto;color:#7e7e7e;font-size:18px;height:100%;padding-right:4px}.clickable{cursor:pointer}.navbar-brand{margin-left:.5em}.logo{max-height:30px}.dropdown-toggle .btn-outline-primary:focus,.dropdown-toggle .btn-outline-primary:visited{border-color:inherit;box-shadow:none}"]
    }),
    __param(1, Inject(LUMILOGIN_URL)),
    __param(2, Inject(LUMILOGIN_REALM)),
    __param(3, Inject(APPLICATION_NAME)),
    __param(4, Inject(SHOW_SEARCH_BAR)),
    __param(5, Inject(SHOW_LANG_SELECTOR)),
    __metadata("design:paramtypes", [LumiloginService, String, String, String, Boolean, Boolean, TranslationLoaderService,
        NavigationService])
], HeaderComponent);

let FooterComponent = class FooterComponent {
    constructor(_translateService, _translationLoaderService, doc_url, show_help, show_cgu) {
        this._translateService = _translateService;
        this._translationLoaderService = _translationLoaderService;
        this.doc_url = doc_url;
        this.show_help = show_help;
        this.show_cgu = show_cgu;
        this.docUrl = "";
        this.showHelp = false;
        this.showCGU = false;
        this.docUrl = doc_url;
        this.showHelp = show_help;
        this.showCGU = show_cgu;
    }
    ngOnInit() {
        this.year = new Date().getFullYear();
    }
};
FooterComponent = __decorate([
    Component({
        selector: 'app-footer',
        template: "<div class=\"page-footer row\" style=\"border-top: 1px solid #dee1e3;\">                    \n\t\t<div class=\"text-muted col-6 footer-pull-left\">{{year}} \u00A9 <a href=\"https://www.lumiplan.com\" target=\"_blank\"><strong>Lumiplan</strong></a>. {{ 'FOOTER.ALL_RIGHTS_RESERVED' | translate }}</div>\n\t\t<div class=\"text-muted col-6 footer-pull-right\">\n\t\t\t<a *ngIf=\"showCGU\" href=\"\">CGU</a>\n\t\t\t<span *ngIf=\"showCGU && showHelp\" class=\"footer-separator\">|</span>\n\t\t\t<a *ngIf=\"showHelp\" href=\"{{docUrl}}\" target=\"_blanck\">Aide</a></div>\n</div>",
        styles: [".footer-pull-left{text-align:left}.footer-pull-right{text-align:right}.footer-separator{margin:5px}"]
    }),
    __param(2, Inject(DOC_URL)),
    __param(3, Inject(SHOW_HELP)),
    __param(4, Inject(SHOW_CGU)),
    __metadata("design:paramtypes", [TranslateService,
        TranslationLoaderService, String, Boolean, Boolean])
], FooterComponent);

/**
 * An object used to get page information from the server
 */
class Page {
    constructor() {
        //The number of elements in the page
        this.size = 0;
        //The total number of elements
        this.totalElements = 0;
        //The total number of pages
        this.totalPages = 0;
        //The current page number
        this.number = 0;
    }
}

/**
 * An array of data with an associated page object used for paging
 */
class PagedData {
    constructor() {
        this._embedded = new Array();
        this.page = new Page();
    }
}

const Constants = {
    httpStatus: {
        NO_CONTENT: 204
    },
    dateFormat: {
        ISO: 'yyyy-MM-dd',
        DATE_FR: 'dd/MM/yyyy'
    }
};

let WebServicesService = class WebServicesService {
    constructor(urlApiLumilogin, httpClient) {
        this.urlApiLumilogin = urlApiLumilogin;
        this.httpClient = httpClient;
    }
    getList(resourcePath) {
        return this.httpClient.get(this.urlApiLumilogin + resourcePath, { observe: 'response' }).toPromise()
            .then(res => this.extractPagedData(res))
            .catch(this.handleError);
    }
    getEntity(resourcePath) {
        return this.httpClient.get(this.urlApiLumilogin + resourcePath, { observe: 'response' }).toPromise()
            .then(res => this.extractData(res))
            .catch(this.handleError);
    }
    getBlob(resourcePath) {
        return this.httpClient.get(this.urlApiLumilogin + resourcePath, { responseType: 'blob' }).toPromise()
            .catch(this.handleError);
    }
    post(resourcePath, jsonBody) {
        return this.httpClient.post(this.urlApiLumilogin + resourcePath, jsonBody, { observe: 'response', headers: this.newJsonHeaders() }).toPromise()
            .then(res => this.extractData(res))
            .catch(this.handleError);
    }
    put(resourcePath, jsonBody) {
        return this.httpClient.put(this.urlApiLumilogin + resourcePath, jsonBody, { observe: 'response', headers: this.newJsonHeaders() }).toPromise()
            .then(res => this.extractData(res))
            .catch(this.handleError);
    }
    postFile(resourcePath, file) {
        let formData = new FormData();
        formData.append('file', file, file.name);
        return this.httpClient.post(this.urlApiLumilogin + resourcePath, formData, { observe: 'response', headers: this.newFileHeaders() }).toPromise()
            .then(this.extractData)
            .catch(this.handleError);
    }
    patch(resourcePath, jsonBody) {
        return this.httpClient.patch(this.urlApiLumilogin + resourcePath, jsonBody, { observe: 'response', headers: this.newJsonHeaders() }).toPromise()
            .then(res => this.extractData(res))
            .catch(this.handleError);
    }
    delete(resourcePath) {
        return this.httpClient.delete(this.urlApiLumilogin + resourcePath, { observe: 'response', headers: this.newJsonHeaders() }).toPromise()
            .then(this.extractData)
            .catch(this.handleError);
    }
    extractData(response) {
        if (response.status === Constants.httpStatus.NO_CONTENT)
            return null;
        return response.body;
    }
    extractPagedData(response) {
        if (response.status === Constants.httpStatus.NO_CONTENT)
            return new PagedData();
        return response.body;
    }
    handleError(response) {
        console.log('=== Erreur web services ===');
        if (response.body) {
            console.log(response.body);
            return Promise.reject(response.body);
        }
        else {
            console.log(response);
            return Promise.reject(response);
        }
    }
    newJsonHeaders() {
        return new HttpHeaders({ 'Content-Type': 'application/json' });
    }
    newFileHeaders() {
        return new HttpHeaders({ 'Accept': 'application/json' });
    }
};
WebServicesService = __decorate([
    Injectable(),
    __param(0, Inject(URL_API_LUMILOGIN)),
    __metadata("design:paramtypes", [String, HttpClient])
], WebServicesService);

let NotificationService = class NotificationService {
    constructor(toastrService, translateService) {
        this.toastrService = toastrService;
        this.translateService = translateService;
    }
    showSuccess(message, title = this.translateService.instant('NOTIFICATION.SUCCESS'), timeOutInSeconds = 3) {
        try {
            return this.toastrService.success(message, title, { timeOut: timeOutInSeconds * 1000 });
        }
        catch (error) {
            console.log(error);
            return null;
        }
    }
    showInfo(message, title = this.translateService.instant('NOTIFICATION.INFO'), timeOutInSeconds = 5) {
        try {
            return this.toastrService.info(message, title, { timeOut: timeOutInSeconds * 1000 });
        }
        catch (error) {
            console.log(error);
            return null;
        }
    }
    showWarning(message, title = this.translateService.instant('NOTIFICATION.WARNING'), timeOutInSeconds = 5) {
        try {
            return this.toastrService.warning(message, title, { timeOut: timeOutInSeconds * 1000 });
        }
        catch (error) {
            console.log(error);
            return null;
        }
    }
    showError(message, title = this.translateService.instant('NOTIFICATION.ERROR'), timeOutInSeconds = 5) {
        try {
            return this.toastrService.error(message, title, { timeOut: timeOutInSeconds * 1000 });
        }
        catch (error) {
            console.log(error);
            return null;
        }
    }
    clearAll() {
        try {
            this.toastrService.clear();
        }
        catch (error) {
            console.log(error);
            return null;
        }
    }
    clear(toast) {
        try {
            this.toastrService.clear(toast);
        }
        catch (error) {
            console.log(error);
            return null;
        }
    }
};
NotificationService.ngInjectableDef = defineInjectable({ factory: function NotificationService_Factory() { return new NotificationService(inject(ToastrService), inject(TranslateService)); }, token: NotificationService, providedIn: "root" });
NotificationService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [ToastrService,
        TranslateService])
], NotificationService);

let CustomerTreeService = class CustomerTreeService {
    constructor(notificationService, translateService, webServicesService) {
        this.notificationService = notificationService;
        this.translateService = translateService;
        this.webServicesService = webServicesService;
    }
    /* Appels aux webServices */
    getCustomerTree() {
        console.log('Récupération de l\'arborescence client');
        return this.webServicesService.getEntity('/customer_tree')
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('GET_CUSTOMER_TREE_ERROR'));
            return Promise.reject(error);
        });
    }
    getCustomerTreeElement(customerTreeId) {
        console.log('Récupération de l\'élément ' + customerTreeId + 'dans l\'arborescence client');
        return this.webServicesService.getEntity('/customer_tree/' + customerTreeId)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('GET_CUSTOMER_TREE_ERROR'));
            return Promise.reject(error);
        });
    }
    // TODO: récupérer un Customer Tree
    putCustomerTreeElement(name, alternateName, parentId, languages, timeZone, type) {
        console.log('Ajout d\'un élément dans l\'arborescence client');
        let json = {
            name: name,
            alternateName: alternateName,
            languages: languages,
            timeZone: timeZone,
            type: type
        };
        return this.webServicesService.put('/customer_tree/' + parentId, json)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
    patchCustomerTreeElement(id, name, alternateName, parentId, languages, timeZone, type) {
        console.log('Modification de l\'élément ' + id + ' dans l\'arborescence client');
        let json = {
            name: name,
            alternateName: alternateName,
            parentId: parentId,
            languages: languages,
            timeZone: timeZone,
            type: type
        };
        return this.webServicesService.patch('/customer_tree/' + id, json)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
    deleteCustomerTreeLevel(levelId) {
        console.log("Suppression du niveau " + levelId + ' dans l\'arborescence client');
        return this.webServicesService.delete('/customer_tree/' + levelId)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
};
CustomerTreeService.ngInjectableDef = defineInjectable({ factory: function CustomerTreeService_Factory() { return new CustomerTreeService(inject(NotificationService), inject(TranslateService), inject(WebServicesService)); }, token: CustomerTreeService, providedIn: "root" });
CustomerTreeService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [NotificationService,
        TranslateService,
        WebServicesService])
], CustomerTreeService);

class CustomerTree {
}

let ConfirmDialogComponent = class ConfirmDialogComponent {
    constructor(dialogRef) {
        this.dialogRef = dialogRef;
    }
};
ConfirmDialogComponent = __decorate([
    Component({
        selector: 'confirm-dialog',
        template: "<h1 matDialogTitle>{{'CONFIRM_DIALOG.CONFIRMATION' | translate}}</h1>\n<div mat-dialog-content>{{confirmMessage}}</div>\n<br>\n<div mat-dialog-actions class=\"pull-right\">\n\t<button class=\"btn btn-rounded btn-primary mr-2\" (click)=\"dialogRef.close(true)\">{{'CONFIRM_DIALOG.CONFIRM' | translate}}</button>\n\t<button class=\"btn btn-rounded btn-secondary\" (click)=\"dialogRef.close(false)\">{{'CONFIRM_DIALOG.CANCEL' | translate}}</button>\n</div>",
        styles: [""]
    }),
    __metadata("design:paramtypes", [MatDialogRef])
], ConfirmDialogComponent);

let CanDeactivateGuard = class CanDeactivateGuard {
    constructor(translateService, matDialog) {
        this.translateService = translateService;
        this.matDialog = matDialog;
        this.unsavedChanges = false;
    }
    setUnsavedChanges(unsavedChanges) {
        this.unsavedChanges = unsavedChanges;
    }
    canDeactivate() {
        if (this.unsavedChanges) {
            return this.askConfirmation().then(confirmed => {
                if (confirmed)
                    this.unsavedChanges = false;
                return confirmed;
            });
        }
        else {
            return Promise.resolve(true);
        }
    }
    askConfirmation() {
        let confirmDialogRef = this.matDialog.open(ConfirmDialogComponent, { disableClose: false });
        confirmDialogRef.componentInstance.confirmMessage = this.translateService.instant('CONFIRM_UNSAVED_CHANGES');
        return confirmDialogRef.afterClosed().toPromise().then(confirmed => { return confirmed; });
    }
};
CanDeactivateGuard.ngInjectableDef = defineInjectable({ factory: function CanDeactivateGuard_Factory() { return new CanDeactivateGuard(inject(TranslateService), inject(MatDialog)); }, token: CanDeactivateGuard, providedIn: "root" });
CanDeactivateGuard = __decorate([
    Injectable({
        providedIn: 'root',
    }),
    __metadata("design:paramtypes", [TranslateService,
        MatDialog$1])
], CanDeactivateGuard);

let SubheaderComponent = class SubheaderComponent {
    constructor(customerTreeService, canDeactivateGuard) {
        this.customerTreeService = customerTreeService;
        this.canDeactivateGuard = canDeactivateGuard;
        this.SELECT_LEVEL_NAME = '...';
        this.inputLevelId = 0;
        this.selectionChange = new EventEmitter();
        this.userHomeLevelId = 83;
        this.customerTree = null;
        this.customerTreeForId = new Map();
        this.selectedLevel = null;
        this.breadcrumbLevels = [];
        this.customerTreeService.getCustomerTree()
            .then(customerTree => {
            this.customerTree = customerTree;
            this.prepareCustomerTree(customerTree);
            if (this.customerTreeForId.has(this.inputLevelId))
                this.setSelectedLevel(this.inputLevelId);
            else if (this.customerTreeForId.has(this.userHomeLevelId))
                this.setSelectedLevel(this.userHomeLevelId);
            else
                this.setSelectedLevel(this.customerTree.id);
        });
    }
    ngOnInit() { }
    ngOnChanges() {
        if (this.customerTree && this.inputLevelId)
            this.setSelectedLevel(this.inputLevelId);
    }
    // Méthode récursive pour mapper chaque niveau de l'arborescence descendante avec son ID et ajouter un niveau de sélection à chaque parent
    prepareCustomerTree(customerTree) {
        this.customerTreeForId.set(customerTree.id, customerTree);
        if (customerTree.children) {
            let selectLevel = new CustomerTree();
            selectLevel.name = this.SELECT_LEVEL_NAME;
            selectLevel.parentId = customerTree.id;
            customerTree.children.push(selectLevel);
            for (let child of customerTree.children) {
                this.prepareCustomerTree(child);
            }
        }
    }
    setSelectedLevel(selectedLevelId) {
        this.selectedLevel = this.customerTreeForId.get(selectedLevelId);
        if (!this.selectedLevel)
            this.selectedLevel = this.customerTree;
        this.inputLevelId = this.selectedLevel.id;
        this.breadcrumbLevels = this.getBreadcrumbLevels(this.selectedLevel, []);
        let selectedLevelCopy = JSON.parse(JSON.stringify(this.selectedLevel));
        selectedLevelCopy.children = selectedLevelCopy.children.filter(level => level.id);
        this.selectionChange.emit(selectedLevelCopy);
    }
    // Méthode récursive pour construire le fil d'arianne en remontant l'arborescence
    getBreadcrumbLevels(level, breadcrumbLevels) {
        if (breadcrumbLevels.length === 0 && level.children && level.children.length > 1) {
            breadcrumbLevels.unshift(level.children.find(child => !child.id));
        }
        breadcrumbLevels.unshift(level);
        let parent = this.customerTreeForId.get(level.parentId);
        if (parent)
            this.getBreadcrumbLevels(parent, breadcrumbLevels);
        return breadcrumbLevels;
    }
    getBrothers(level) {
        let parent = this.customerTreeForId.get(level.parentId);
        if (parent) {
            return parent.children;
        }
        else {
            return [level];
        }
    }
    onHomeClick() {
        this.canDeactivateGuard.canDeactivate().then(canDeactivate => {
            if (canDeactivate)
                this.setSelectedLevel(this.userHomeLevelId);
        });
    }
    onOpenedChange(matSelect) {
        if (matSelect.panelOpen) {
            this.canDeactivateGuard.canDeactivate().then(canDeactivate => {
                if (!canDeactivate)
                    matSelect.close();
            });
        }
    }
    onSelectLevel(level) {
        if (level.id)
            this.setSelectedLevel(level.id);
        else
            this.setSelectedLevel(level.parentId);
    }
};
__decorate([
    Input('selectedLevelId'),
    __metadata("design:type", Number)
], SubheaderComponent.prototype, "inputLevelId", void 0);
__decorate([
    Output('selectionChange'),
    __metadata("design:type", EventEmitter)
], SubheaderComponent.prototype, "selectionChange", void 0);
SubheaderComponent = __decorate([
    Component({
        selector: 'subheader',
        template: "<div class=\"page-heading\" id=\"subheader\">\n\t<h1 *ngIf=\"selectedLevel\" class=\"page-title page-title-sep\">{{selectedLevel.alternateName || selectedLevel.name}}</h1>\n\t<ol class=\"breadcrumb\" *ngIf=\"breadcrumbLevels\">\n\t\t<li class=\"breadcrumb-item clickable\" (click)=\"onHomeClick()\">\n\t\t\t<i class=\"la la-home font-20\"></i>\n\t\t</li>\n\t\t<li class=\"breadcrumb-item\" *ngFor=\"let level of breadcrumbLevels\">\n\t\t\t<mat-form-field>\n\t\t\t\t<mat-select #levelSelect [value]=\"level\" (openedChange)=\"onOpenedChange(levelSelect)\" (selectionChange)=\"onSelectLevel($event.value)\">\n\t\t\t\t\t<mat-option *ngFor=\"let brotherLevel of getBrothers(level)\" [value]=\"brotherLevel\">\n\t\t\t\t\t\t{{brotherLevel.alternateName || brotherLevel.name}}\n\t\t\t\t\t</mat-option>\n\t\t\t\t</mat-select>\n\t\t\t</mat-form-field>\n\t\t</li>\n\t</ol>\n</div>",
        styles: [".page-heading{max-height:25px}mat-option{font-family:Poppins,sans-serif;font-size:13px}#subheader::ng-deep .mat-form-field-underline{display:none}#subheader::ng-deep mat-select .mat-select-arrow{display:none}#subheader::ng-deep mat-select{width:-webkit-fit-content!important;width:-moz-fit-content!important;width:fit-content!important;min-width:100%}#subheader::ng-deep .mat-form-field-infix{width:-webkit-fit-content!important;width:-moz-fit-content!important;width:fit-content!important}#subheader::ng-deep mat-select .mat-select-value{width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;min-width:5ch;max-width:25ch;padding-top:7px;font-family:Poppins,sans-serif;font-size:13px;color:#868e96}#subheader::ng-deep mat-select .mat-select-value:hover{color:#000}#subheader::ng-deep mat-select .mat-select-placeholder{width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}"]
    }),
    __metadata("design:paramtypes", [CustomerTreeService,
        CanDeactivateGuard])
], SubheaderComponent);

let SubheaderModule = class SubheaderModule {
};
SubheaderModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            TranslateModule,
            MatSelectModule,
            FormsModule
        ],
        declarations: [SubheaderComponent],
        exports: [SubheaderComponent]
    })
], SubheaderModule);

let NavigationComponent = class NavigationComponent {
    constructor(navigationService) {
        this.navigationService = navigationService;
        this.display = [];
        this.navigation = [];
        this.navigation = this.navigationService.getNavigation();
        this.navigationService.navigationChange.subscribe(navigation => this.navigation = navigation);
    }
    ngOnInit() { }
    toggleHiddeItems(i, j) {
        for (let key in this.display) {
            let value = this.display[key];
            let myI = key.split("-")[0];
            let myJ = key.split("-")[1];
            if (String(i) != String(myI) || (myJ.length > 0 && String(j) != String(myJ))) {
                this.display[key] = 0;
            }
        }
        this.display[i + '-' + j] = !this.display[i + '-' + j];
    }
    toggleHiddeAllItems() {
        for (let key in this.display) {
            this.display[key] = 0;
        }
    }
};
NavigationComponent = __decorate([
    Component({
        selector: 'navigation',
        template: "<ul class=\"nav header-menu position-static\" id=\"header-nav\">\n\t<ng-container *ngFor=\"let item of navigation;let i = index\">\n\t\t<ng-container *ngIf=\"!item.childrens; else hasChildBlock\">\n\t\t\t<li *ngIf=\"!item.exact\" class=\"nav-item\">\n\t\t\t\t<a *ngIf=\"!item.subtitle\" class=\"header-menu-toggle dropdown-toggle no-arrow\" routerLink=\"{{item.url}}\" routerLinkActive=\"active\">\n\t\t\t\t\t<i class=\"nav-item-icon\" [ngClass]=\"item.icon\"></i>\n\t\t\t\t\t<span class=\"nav-label\">\n\t\t\t\t\t\t{{(item.translate | translate) || item.title}}\n\t\t\t\t\t</span>\n\t\t\t\t</a>\n\t\t\t\t<a *ngIf=\"item.subtitle\" class=\"header-menu-toggle dropdown-toggle no-arrow py-1\" routerLink=\"{{item.url}}\" routerLinkActive=\"active\">\n\t\t\t\t\t<i class=\"nav-item-icon\" [ngClass]=\"item.icon\"></i>\n\t\t\t\t\t<span class=\"nav-label flexbox flex-column\" style=\"font-size: 12px\">\n\t\t\t\t\t\t<span>{{(item.translate | translate) || item.title}}</span>\n\t\t\t\t\t\t<span style=\"color: lightslategray\">{{item.subtitle}}</span>\n\t\t\t\t\t</span>\n\t\t\t\t</a>\n\t\t\t</li>\n\t\t\t<li *ngIf=\"item.exact\" class=\"nav-item\">\n\t\t\t\t<a class=\"header-menu-toggle dropdown-toggle no-arrow\" routerLink=\"{{item.url}}\" routerLinkActive=\"active\" [routerLinkActiveOptions]=\"{exact:true}\">\n\t\t\t\t\t<i class=\"nav-item-icon\" [ngClass]=\"item.icon\"></i>\n\t\t\t\t\t<span class=\"nav-label\">{{(item.translate | translate) || item.title}}</span>\n\t\t\t\t</a>\n\t\t\t</li>\n\t\t</ng-container>\n\n\t\t<ng-template #hasChildBlock>\n\t\t\t<li routerLinkActive=\"active\" class=\"nav-item dropdown\">\n\t\t\t\t<a class=\"header-menu-toggle dropdown-toggle\" href=\"javascript:;\" (click)=\"toggleHiddeItems(i,'')\">\n\t\t\t\t\t<i class=\"nav-item-icon\" [ngClass]=\"item.icon\"></i>\n\t\t\t\t\t<span class=\"nav-label\">{{(item.translate | translate) || item.title}}</span>\n\t\t\t\t</a>\n\t\t\t\t<div class=\"dropdown-menu\" [ngClass]=\"{ 'show': display[i + '-'] }\" x-placement=\"bottom-start\"\n\t\t\t\t\tstyle=\"position: absolute; will-change: transform; top: 0px; left: 0px; transform: translate3d(0px, 50px, 0px);\">\n\t\t\t\t\t<ng-container *ngFor=\"let child of item.childrens;let j = index\">\n\t\t\t\t\t\t<ng-container *ngIf=\"!child.childrens\">\n\t\t\t\t\t\t\t<a class=\"dropdown-item d-flex align-items-center\" routerLink=\"{{item.url + child.url}}\" routerLinkActive=\"active\" (mouseenter)=\"toggleHiddeItems(i,j)\"\n\t\t\t\t\t\t\t\t(click)=\"toggleHiddeAllItems()\">\n\t\t\t\t\t\t\t\t<i class=\"nav-item-icon\" [ngClass]=\"child.icon\"></i>\n\t\t\t\t\t\t\t\t<span class=\"nav-label\">{{(child.translate | translate) || child.title}}</span>\n\t\t\t\t\t\t\t</a>\n\n\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t<ng-container *ngIf=\"child.childrens\">\n\t\t\t\t\t\t\t<a class=\"dropdown-item d-flex align-items-center\" href=\"javascript:;\" (click)=\"toggleHiddeItems(i,j)\">\n\t\t\t\t\t\t\t\t<i class=\"nav-item-icon\" [ngClass]=\"child.icon\"></i>\n\t\t\t\t\t\t\t\t<span class=\"nav-label\">{{(child.translate | translate) || child.title}}</span>\n\t\t\t\t\t\t\t\t<i class=\"arrow la\" [ngClass]=\"{'la-angle-up': display[i + '-' + j], 'la-angle-down': !display[i + '-' + j]}\"></i>\n\t\t\t\t\t\t\t</a>\n\t\t\t\t\t\t\t<ng-container *ngFor=\"let child2 of child.childrens\">\n\t\t\t\t\t\t\t\t<a class=\"dropdown-item d-flex align-items-center level2\" [ngClass]=\"{ 'hidden': !display[i + '-' + j] }\" routerLink=\"{{item.url + child.url + child2.url}}\"\n\t\t\t\t\t\t\t\t\trouterLinkActive=\"active\" (click)=\"toggleHiddeAllItems()\">\n\t\t\t\t\t\t\t\t\t<i class=\"nav-item-icon\" [ngClass]=\"child2.icon\"></i>\n\t\t\t\t\t\t\t\t\t<span class=\"nav-label\">{{(child2.translate | translate) || child2.title}}</span>\n\t\t\t\t\t\t\t\t</a>\n\t\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t\t</ng-container>\n\t\t\t\t\t</ng-container>\n\t\t\t\t</div>\n\t\t\t</li>\n\t\t</ng-template>\n\t</ng-container>\n</ul>",
        styles: [""]
    }),
    __metadata("design:paramtypes", [NavigationService])
], NavigationComponent);

let NavigationModule = class NavigationModule {
};
NavigationModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            RouterModule,
            TranslateModule
        ],
        declarations: [NavigationComponent],
        exports: [NavigationComponent]
    })
], NavigationModule);

let ComponenRegistryService = class ComponenRegistryService {
    constructor() {
        this._registry = {};
        this.onRegistryChanged = new BehaviorSubject(this._registry);
    }
    register(key, component) {
        // Check if the key already being used
        if (this._registry[key]) {
            console.error(`The component with the key '${key}' already exists.`);
            return;
        }
        // Add to the registry
        this._registry[key] = component;
        this.onRegistryChanged.next(this._registry);
    }
    unregister(key) {
        // Check if the component exists
        if (!this._registry[key]) {
            console.warn(`The component with the key '${key}' doesn't exist in the registry.`);
        }
        else {
            // Unregister the component
            delete this._registry[key];
        }
    }
    /**
     * Return the component with the given key
     */
    getComponent(key) {
        // Check if the component exists
        if (!this._registry[key]) {
            console.warn(`The component with the key '${key}' doesn't exist in the registry.`);
            return;
        }
        // Return the component
        return this._registry[key];
    }
};
ComponenRegistryService.ngInjectableDef = defineInjectable({ factory: function ComponenRegistryService_Factory() { return new ComponenRegistryService(); }, token: ComponenRegistryService, providedIn: "root" });
ComponenRegistryService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [])
], ComponenRegistryService);

let BackdropService = class BackdropService {
    constructor() {
        this.open = new EventEmitter();
        this.close = new EventEmitter();
    }
    show() {
        this.open.emit();
    }
    hide() {
        this.close.emit();
    }
};
BackdropService.ngInjectableDef = defineInjectable({ factory: function BackdropService_Factory() { return new BackdropService(); }, token: BackdropService, providedIn: "root" });
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], BackdropService.prototype, "open", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], BackdropService.prototype, "close", void 0);
BackdropService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [])
], BackdropService);

let HeadernavComponent = class HeadernavComponent {
    constructor(_el, renderer, _backdropService, _componenRegistryService) {
        this._el = _el;
        this.renderer = renderer;
        this._backdropService = _backdropService;
        this._componenRegistryService = _componenRegistryService;
        this._HeadernavDrawerMode = false;
        this._HeadernavAlwaysDrawerMode = false;
        this._folded = false;
    }
    ngOnInit() {
        // Register the component in registry
        this._componenRegistryService.register('headernav', this);
        this._backdropService.close.subscribe(() => {
            if (this._HeadernavDrawerMode && this.opened) {
                this._hideHeadernav();
            }
        });
        this.toggleDrawerHeadernavMode();
    }
    ngOnDestroy() {
        this.hide();
    }
    ngAfterViewInit() { }
    headernavToggleHandler() {
        if (this._HeadernavDrawerMode) {
            this.toggleDrawerHeadernav();
        }
        else {
            document.body.classList.toggle('header-nav-hidden');
        }
    }
    toggleDrawerHeadernav() {
        if (this.opened) {
            this.hide();
        }
        else {
            this.show();
        }
    }
    show() {
        if (!this._HeadernavDrawerMode)
            return;
        this._backdropService.show();
        this._showHeadernav();
    }
    hide() {
        if (!this._HeadernavDrawerMode)
            return;
        this._backdropService.hide();
        //this._hideHeadernav();
    }
    _showHeadernav() {
        this.opened = true;
        this.renderer.addClass(this._el.nativeElement, 'shined');
        document.getElementById('header-nav').classList.add('shined');
    }
    _hideHeadernav() {
        if (this.opened) {
            this.opened = false;
            this.renderer.removeClass(this._el.nativeElement, 'shined');
            document.getElementById('header-nav').classList.remove('shined');
        }
    }
    toggleDrawerHeadernavMode() {
        if (this._HeadernavAlwaysDrawerMode) {
            return;
        }
        if (this._canSetDrawerMode() && !this._HeadernavDrawerMode) {
            this._setDrawerHeadernavMode();
        }
        else if (!this._canSetDrawerMode() && this._HeadernavDrawerMode) {
            this._removeDrawerHeadernavMode();
        }
    }
    _setDrawerHeadernavMode() {
        document.body.classList.add('drawer-menu');
        this._HeadernavDrawerMode = true;
    }
    _removeDrawerHeadernavMode() {
        document.body.classList.remove('drawer-menu');
        this._HeadernavDrawerMode = false;
    }
    _canSetDrawerMode() {
        return (window.innerWidth < 992 && !document.body.classList.contains('mini-headernav'));
    }
    onResize() {
        this.toggleDrawerHeadernavMode();
    }
};
__decorate([
    HostListener('window:resize'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], HeadernavComponent.prototype, "onResize", null);
HeadernavComponent = __decorate([
    Component({
        selector: 'app-header-nav',
        template: "<navigation></navigation>\n",
        styles: [""]
    }),
    __metadata("design:paramtypes", [ElementRef,
        Renderer2,
        BackdropService,
        ComponenRegistryService])
], HeadernavComponent);

let HeadernavModule = class HeadernavModule {
};
HeadernavModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            RouterModule,
            NavigationModule,
            PerfectScrollbarModule,
        ],
        declarations: [HeadernavComponent],
        exports: [HeadernavComponent]
    })
], HeadernavModule);

let ApplicationService = class ApplicationService {
    constructor(notificationService, translateService, webServicesService) {
        this.notificationService = notificationService;
        this.translateService = translateService;
        this.webServicesService = webServicesService;
    }
    /* Appels aux webServices */
    // TODO: traduire le nom
    getApplications(page, sort, dir) {
        console.log('Récupération des applications');
        let promise;
        if (page) {
            if (sort && dir) {
                promise = this.webServicesService.getList('/application?size=' + page.size + '&page=' + page.number + '&sort=' + sort + ',' + dir);
            }
            else {
                promise = this.webServicesService.getList('/application?size=' + page.size + '&page=' + page.number);
            }
        }
        else {
            promise = this.webServicesService.getList('/application');
        }
        return promise
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('GET_APPS_ERROR'));
            return Promise.reject(error);
        });
    }
    postApplication(application) {
        console.log('Ajout d\'une nouvelle application');
        let json = {
            name: application.name,
            logo: application.logo,
            adminUrl: application.adminUrl,
            appUrl: application.appUrl
        };
        return this.webServicesService.post('/application', json)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
    patchApplication(application) {
        console.log('Modification de l\'application ' + application.id);
        let json = {
            name: application.name,
            logo: application.logo,
            adminUrl: application.adminUrl,
            appUrl: application.appUrl
        };
        return this.webServicesService.patch('/application/' + application.id, json)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
    deleteApplication(applicationId) {
        console.log("Suppression de l\'application " + applicationId);
        return this.webServicesService.delete('/application/' + applicationId)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
};
ApplicationService.ngInjectableDef = defineInjectable({ factory: function ApplicationService_Factory() { return new ApplicationService(inject(NotificationService), inject(TranslateService), inject(WebServicesService)); }, token: ApplicationService, providedIn: "root" });
ApplicationService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [NotificationService,
        TranslateService,
        WebServicesService])
], ApplicationService);

let RoleService = class RoleService {
    constructor(notificationService, translateService, webServicesService) {
        this.notificationService = notificationService;
        this.translateService = translateService;
        this.webServicesService = webServicesService;
    }
    /* Appels aux webServices */
    getRoles(page, sort, dir) {
        console.log('Récupération des rôles');
        let promise;
        if (page) {
            if (sort && dir) {
                promise = this.webServicesService.getList('/role?size=' + page.size + '&page=' + page.number + '&sort=' + sort + ',' + dir);
            }
            else {
                promise = this.webServicesService.getList('/role?size=' + page.size + '&page=' + page.number);
            }
        }
        else {
            promise = this.webServicesService.getList('/role');
        }
        return promise
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ROLES.GET_ROLES_ERROR'));
            return Promise.reject(error);
        });
    }
    // TODO: Ne plus filtrer le applicationId
    getRolesForApplication(applicationId) {
        console.log('Récupération des rôles de l\'application ' + applicationId);
        return this.webServicesService.getList('/role?applicationId=' + applicationId)
            .then(pagedData => {
            if (pagedData && pagedData._embedded) {
                let roles = pagedData._embedded[Object.keys(pagedData._embedded)[0]];
                roles.sort((a, b) => {
                    if (a.name < b.name)
                        return -1;
                    if (a.name > b.name)
                        return 1;
                    return 0;
                });
                return Promise.resolve(roles.filter(role => role.applicationId === applicationId));
            }
            else
                return Promise.resolve([]);
        })
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('GET_ROLES_ERROR'));
            return Promise.reject(error);
        });
    }
    postRole(role) {
        console.log('Ajout d\'un nouveau rôle');
        let json = {
            applicationId: role.applicationId,
            name: role.name
        };
        return this.webServicesService.post('/role', json)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
    patchRole(role) {
        console.log('Modification du rôle ' + role.id);
        let json = {
            applicationId: role.applicationId,
            name: role.name
        };
        return this.webServicesService.patch('/role/' + role.id, json)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
    deleteRole(role) {
        console.log("Suppression du rôle " + role.id);
        let json = {
            applicationId: role.applicationId,
            name: role.name
        };
        return this.webServicesService.post('/role/delete/' + role.id, json)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
    /* Fonctions utilitaires */
    postRoles(roles) {
        let promises = [];
        for (let role of roles) {
            promises.push(this.postRole(role));
        }
        return Promise.all(promises);
    }
};
RoleService.ngInjectableDef = defineInjectable({ factory: function RoleService_Factory() { return new RoleService(inject(NotificationService), inject(TranslateService), inject(WebServicesService)); }, token: RoleService, providedIn: "root" });
RoleService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [NotificationService,
        TranslateService,
        WebServicesService])
], RoleService);

let UserService = class UserService {
    constructor(notificationService, translateService, webServicesService) {
        this.notificationService = notificationService;
        this.translateService = translateService;
        this.webServicesService = webServicesService;
    }
    /* Appels aux webServices */
    getUsers(page, sort, dir) {
        console.log('Récupération des utilisateurs');
        let promise;
        if (page) {
            if (sort && dir) {
                promise = this.webServicesService.getList('/user?size=' + page.size + '&page=' + page.number + '&sort=' + sort + ',' + dir);
            }
            else {
                promise = this.webServicesService.getList('/user?size=' + page.size + '&page=' + page.number);
            }
        }
        else {
            promise = this.webServicesService.getList('/user');
        }
        return promise
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('GET_USERS_ERROR'));
            return Promise.reject(error);
        });
    }
    postUser(user) {
        console.log('Ajout d\'un nouvel utilisateur');
        let json = {
            firstName: user.firstName,
            lastName: user.lastName,
            email: user.email,
            company: user.company,
            phone: user.phone
        };
        return this.webServicesService.post('/user', json)
            .catch(error => {
            if ((error instanceof HttpErrorResponse) && (error.status == 409)) {
                this.notificationService.showError(this.translateService.instant('POST_PUT_USER_CONFLICT'));
            }
            else {
                this.notificationService.showError(this.translateService.instant('ERROR'));
            }
            return Promise.reject(error);
        });
    }
    patchUser(user) {
        console.log('Modification de l\'utilisateur ' + user.id);
        let json = {
            firstName: user.firstName,
            lastName: user.lastName,
            email: user.email,
            company: user.company,
            phone: user.phone
        };
        return this.webServicesService.patch('/user/' + user.id, json)
            .catch(error => {
            if ((error instanceof HttpErrorResponse) && (error.status == 409)) {
                this.notificationService.showError(this.translateService.instant('POST_PUT_USER_CONFLICT'));
            }
            else {
                this.notificationService.showError(this.translateService.instant('ERROR'));
            }
            return Promise.reject(error);
        });
    }
    deleteUser(userId) {
        console.log('Suppression de l\'utilisateur ' + userId);
        return this.webServicesService.delete('/user/' + userId)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
};
UserService.ngInjectableDef = defineInjectable({ factory: function UserService_Factory() { return new UserService(inject(NotificationService), inject(TranslateService), inject(WebServicesService)); }, token: UserService, providedIn: "root" });
UserService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [NotificationService,
        TranslateService,
        WebServicesService])
], UserService);

let UserAccessService = class UserAccessService {
    constructor(notificationService, translateService, webServicesService) {
        this.notificationService = notificationService;
        this.translateService = translateService;
        this.webServicesService = webServicesService;
    }
    /* Appels aux webServices */
    getUserAccess(userId) {
        console.log('Récupération des droits de l\'utilisateur ' + userId);
        return this.webServicesService.getList('/user_access?userId=' + userId)
            .then(pagedData => {
            if (pagedData && pagedData._embedded)
                return Promise.resolve(pagedData._embedded[Object.keys(pagedData._embedded)[0]]);
            else
                return Promise.resolve([]);
        })
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('GET_USER_ACCESS_ERROR'));
            return Promise.reject(error);
        });
    }
    putUserAccess(applicationId, roleId, userId, customerTreeId, granted) {
        console.log('Ajout d\'un nouveau droit utilisateur');
        let json = {
            applicationId: applicationId,
            roleId: roleId,
            userId: userId,
            customerTreeId: customerTreeId,
            granted: granted
        };
        return this.webServicesService.put('/user_access', json)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
    deleteUserAccess(userAccessId) {
        console.log("Suppression du droit utilisateur " + userAccessId);
        return this.webServicesService.delete('/user_access/' + userAccessId)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
};
UserAccessService.ngInjectableDef = defineInjectable({ factory: function UserAccessService_Factory() { return new UserAccessService(inject(NotificationService), inject(TranslateService), inject(WebServicesService)); }, token: UserAccessService, providedIn: "root" });
UserAccessService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [NotificationService,
        TranslateService,
        WebServicesService])
], UserAccessService);

let UserApplicationService = class UserApplicationService {
    constructor(notificationService, translateService, webServicesService) {
        this.notificationService = notificationService;
        this.translateService = translateService;
        this.webServicesService = webServicesService;
    }
    /* Appels aux webServices */
    getUserApplication(userId) {
        console.log('Récupération des userApplication de l\'utilisateur ' + userId);
        return this.webServicesService.getList('/user_application?userId=' + userId)
            .then(pagedData => {
            if (pagedData && pagedData._embedded)
                return Promise.resolve(pagedData._embedded[Object.keys(pagedData._embedded)[0]]);
            else
                return Promise.resolve([]);
        })
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('GET_USER_APPLICATIONS_ERROR'));
            return Promise.reject(error);
        });
    }
    putUserApplication(userId, applicationId, customerTreeId, visible) {
        console.log('Ajout d\'un nouveau userApplication');
        let json = {
            userId: userId,
            applicationId: applicationId,
            customerTreeId: customerTreeId,
            visible: visible
        };
        return this.webServicesService.put('/user_application', json)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
    deleteUserApplication(userApplicationId) {
        console.log("Suppression du userApplication " + userApplicationId);
        return this.webServicesService.delete('/user_application/' + userApplicationId)
            .catch(error => {
            this.notificationService.showError(this.translateService.instant('ERROR'));
            return Promise.reject(error);
        });
    }
};
UserApplicationService.ngInjectableDef = defineInjectable({ factory: function UserApplicationService_Factory() { return new UserApplicationService(inject(NotificationService), inject(TranslateService), inject(WebServicesService)); }, token: UserApplicationService, providedIn: "root" });
UserApplicationService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [NotificationService,
        TranslateService,
        WebServicesService])
], UserApplicationService);

let ConfirmDialogModule = class ConfirmDialogModule {
};
ConfirmDialogModule = __decorate([
    NgModule({
        declarations: [
            ConfirmDialogComponent
        ],
        imports: [
            TranslateModule,
            MatDialogModule,
            MatButtonModule
        ],
        entryComponents: [
            ConfirmDialogComponent
        ],
        exports: [
            ConfirmDialogComponent
        ],
    })
], ConfirmDialogModule);

var LumiloginModule_1;
let LumiloginModule = LumiloginModule_1 = class LumiloginModule {
    static forRoot(lumilogin_url, lumilogin_realm, lumilogin_clientid, lumilogin_secret, application_name, theme_config, urlApiLumilogin, show_Search_Bar, show_Lang_Selector, doc_url, show_help, show_cgu) {
        return {
            ngModule: LumiloginModule_1,
            providers: [
                {
                    provide: LUMILOGIN_URL,
                    useValue: lumilogin_url
                },
                {
                    provide: LUMILOGIN_REALM,
                    useValue: lumilogin_realm
                },
                {
                    provide: LUMILOGIN_CLIENTID,
                    useValue: lumilogin_clientid
                },
                {
                    provide: LUMILOGIN_SECRET,
                    useValue: lumilogin_secret
                },
                {
                    provide: APPLICATION_NAME,
                    useValue: application_name
                },
                {
                    provide: THEME_CONFIG,
                    useValue: theme_config
                },
                {
                    provide: URL_API_LUMILOGIN,
                    useValue: urlApiLumilogin
                },
                {
                    provide: SHOW_SEARCH_BAR,
                    useValue: show_Search_Bar
                },
                {
                    provide: SHOW_LANG_SELECTOR,
                    useValue: show_Lang_Selector
                },
                {
                    provide: DOC_URL,
                    useValue: doc_url
                },
                {
                    provide: SHOW_HELP,
                    useValue: show_help
                },
                {
                    provide: SHOW_CGU,
                    useValue: show_cgu
                }
            ]
        };
    }
};
LumiloginModule = LumiloginModule_1 = __decorate([
    NgModule({
        declarations: [HeaderComponent, FooterComponent],
        imports: [
            CommonModule,
            HttpClientModule,
            NgbModule,
            TranslateModule,
            FormsModule,
            HeadernavModule,
            ToastrModule.forRoot(),
            ConfirmDialogModule
        ],
        providers: [
            {
                provide: HTTP_INTERCEPTORS,
                useClass: LumiloginInterceptorService,
                multi: true
            },
            DatePipe,
            LumiloginService,
            ApplicationService,
            CustomerTreeService,
            RoleService,
            UserService,
            UserAccessService,
            UserApplicationService,
            WebServicesService
        ],
        exports: [
            HeaderComponent,
            FooterComponent,
            SubheaderModule
        ]
    })
], LumiloginModule);

const locale = {
    lang: 'fr',
    data: {
        HEADER: {
            'LOGIN': 'Se connecter',
            'APPLICATION': 'Apps',
            'PROFILE': 'Profil',
            'SETTINGS': 'Paramètres',
            'LOGOUT': 'Déconnexion',
            'SEARCH': 'Rechercher',
        },
        FOOTER: {
            'ALL_RIGHTS_RESERVED': 'Tous droits réservés',
        },
        NOTIFICATION: {
            SUCCESS: 'Succès',
            INFO: 'Information',
            WARNING: 'Avertissement',
            ERROR: 'Erreur'
        },
        CONFIRM_DIALOG: {
            CONFIRMATION: 'Confirmation',
            CONFIRM: 'Confirmer',
            CANCEL: 'Annuler'
        },
        CUSTOMER_TREE_TYPE: {
            UNDEF: 'Non défini',
            RESORT: 'Station',
            SECTOR: 'Secteur',
            ZONE: 'Zone météo'
        },
        CONFIRM_UNSAVED_CHANGES: 'Vous n\'avez pas enregistré vos changements, voulez-vous continuer ?',
        ERROR: 'Une erreur est survenue!',
        POST_PUT_USER_CONFLICT: 'Il existe déjà un utilisateur avec cette adresse mail',
        GET_APPS_ERROR: 'Une erreur est survenue lors de la récupération des applications!',
        GET_CUSTOMER_TREE_ERROR: 'Une erreur est survenue lors de la récupération de l\'arborescence client!',
        GET_USERS_ERROR: 'Une erreur est survenue lors de la récupération des utilisateurs!',
        GET_USER_ACCESS_ERROR: 'Une erreur est survenue lors de la récupération des droits utilisateur!',
        GET_USER_APPLICATIONS_ERROR: 'Une erreur est survenue lors de la récupération des applications utilisateur!'
    }
};

const locale$1 = {
    lang: 'en',
    data: {
        HEADER: {
            'LOGIN': 'Log in',
            'APPLICATION': 'Apps',
            'PROFILE': 'Profile',
            'SETTINGS': 'Settings',
            'LOGOUT': 'Logout',
            'SEARCH': 'Search',
        },
        FOOTER: {
            'ALL_RIGHTS_RESERVED': 'All rights reserved',
        },
        NOTIFICATION: {
            SUCCESS: 'Success',
            INFO: 'Information',
            WARNING: 'Warning',
            ERROR: 'Error'
        },
        CONFIRM_DIALOG: {
            CONFIRMATION: 'Confirmation',
            CONFIRM: 'Confirm',
            CANCEL: 'Cancel'
        },
        CUSTOMER_TREE_TYPE: {
            UNDEF: 'Undefined',
            RESORT: 'Resort',
            SECTOR: 'Sector',
            ZONE: 'Weather zone'
        },
        CONFIRM_UNSAVED_CHANGES: 'You have not saved your changes, do you want to continue ?',
        ERROR: 'An error occured!',
        POST_PUT_USER_CONFLICT: 'There is already a user with this email address',
        GET_APPS_ERROR: 'An error occured while getting applications!',
        GET_CUSTOMER_TREE_ERROR: 'An error occurer while getting customer tree!',
        GET_USERS_ERROR: 'An error occured while getting users!',
        GET_USER_ACCESS_ERROR: 'An error occured while getting user access!',
        GET_USER_APPLICATIONS_ERROR: 'An error occured while getting user applications!'
    }
};

let ThemeConfigService = class ThemeConfigService {
    constructor(config) {
        this.config = config;
        this._configSubject = new BehaviorSubject(this.config);
    }
    setModel(model) {
        this.config = Object.assign({}, this.config, model);
        this._configSubject.next(this.config);
    }
};
ThemeConfigService.ngInjectableDef = defineInjectable({ factory: function ThemeConfigService_Factory() { return new ThemeConfigService(inject(THEME_CONFIG)); }, token: ThemeConfigService, providedIn: "root" });
ThemeConfigService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __param(0, Inject(THEME_CONFIG)),
    __metadata("design:paramtypes", [Object])
], ThemeConfigService);

class Application {
}

var CustomerTreeTypesEnum;
(function (CustomerTreeTypesEnum) {
    CustomerTreeTypesEnum["UNDEF"] = "UNDEF";
    CustomerTreeTypesEnum["RESORT"] = "RESORT";
    CustomerTreeTypesEnum["SECTOR"] = "SECTOR";
    CustomerTreeTypesEnum["ZONE"] = "ZONE";
})(CustomerTreeTypesEnum || (CustomerTreeTypesEnum = {}));

class Role {
}

class User {
}

class UserAccess {
}

class UserApplication {
}

/**
 * Generated bundle index. Do not edit.
 */

export { Application, ApplicationService, BackdropService, CanDeactivateGuard, ComponenRegistryService, ConfirmDialogComponent, CustomerTree, CustomerTreeService, CustomerTreeTypesEnum, LumiloginModule, LumiloginService, NavigationModule, NavigationService, Page, PagedData, Role, RoleService, SubheaderModule, ThemeConfigService, TranslationLoaderService, User, UserAccess, UserAccessService, UserApplication, UserApplicationService, UserService, locale$1 as enLang, locale as frLang, HeaderComponent as ɵa, LUMILOGIN_URL as ɵb, LUMILOGIN_REALM as ɵc, LUMILOGIN_CLIENTID as ɵd, LUMILOGIN_SECRET as ɵe, APPLICATION_NAME as ɵf, THEME_CONFIG as ɵg, URL_API_LUMILOGIN as ɵh, SHOW_SEARCH_BAR as ɵi, SHOW_LANG_SELECTOR as ɵj, DOC_URL as ɵk, SHOW_HELP as ɵl, SHOW_CGU as ɵm, FooterComponent as ɵn, HeadernavModule as ɵo, NavigationComponent as ɵp, HeadernavComponent as ɵq, ConfirmDialogModule as ɵr, LumiloginInterceptorService as ɵs, NotificationService as ɵt, WebServicesService as ɵu, SubheaderComponent as ɵv };
//# sourceMappingURL=lumiloginjs.js.map
